@@ -51,7 +51,7 @@ class ftpUtil:
             # item['filename'] = local_path
             # item['url'] = self.__url_head+remote_file
             # item['stud'] = stud
-            self.__mutil.sftp_file_ins(local_path, self.__url_head + remote_file, stud,desc)
+            self.__mutil.sftp_file_ins(local_path, self.__url_head +'/' +prj +'/'+ remote_file, stud,desc)
         except Exception as ex:
             print("日志记录出现如下异常%s" % ex)
 
